class formula:
    def add(a,b):
        return a+b
    def substract(a,b):
        return a-b
    def multiply(a,b):
        return a*b
    def divide(a,b):
        return a/b
    def square(a):
        return a*a
    def power(a,b):
        return a**b